/* eslint-disable @stencil/strict-boolean-conditions */
import { Component, Host, h, Prop, Event } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import { formatName, shorten } from '../../utils/string';
import { getInitials } from '../dyte-avatar/utils';
/**
 * A poll component.
 *
 * Shows a poll where a user can vote.
 */
export class DytePolls {
  constructor() {
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
  }
  vote(e, index) {
    if (this.poll.voted.includes(this.self)) {
      e.preventDefault();
    }
    else {
      this.onVote.emit({ id: this.poll.id, index });
    }
  }
  render() {
    return (h(Host, null,
      h("div", { class: "ctr" },
        h("p", { class: "poll-title" },
          this.t('Poll by'),
          " ",
          shorten(formatName(this.poll.createdBy), 20)),
        h("div", { class: "poll" },
          h("p", { class: "poll-question" }, this.poll.question),
          this.poll.options.map((item, index) => (h("div", { class: {
              active: !!item.votes.find((x) => x.id === this.self),
              'poll-option': true,
            } },
            h("div", { class: "poll-option-header" },
              h("label", null,
                h("input", { type: "checkbox", checked: !!item.votes.find((x) => x.id === this.self), onClick: (e) => this.vote(e, index) }),
                h("p", null, item.text)),
              h("p", null,
                "(",
                item.count,
                ")")),
            h("div", { class: "votes" }, !this.poll.anonymous &&
              item.votes.map((vote) => {
                return (h("dyte-tooltip", { label: vote.name },
                  h("div", { class: "vote" }, getInitials(vote.name))));
              })))))))));
  }
  static get is() { return "dyte-poll"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-poll.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-poll.css"]
  }; }
  static get properties() { return {
    "poll": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Poll",
        "resolved": "Poll",
        "references": {
          "Poll": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Poll"
      }
    },
    "self": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Self ID"
      },
      "attribute": "self",
      "reflect": false
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get events() { return [{
      "method": "onVote",
      "name": "dyteVotePoll",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Event which is emitted when a poll is voted on"
      },
      "complexType": {
        "original": "{\n    id: string;\n    index: number;\n  }",
        "resolved": "{ id: string; index: number; }",
        "references": {}
      }
    }]; }
}
