import { Component, Host, h, Prop, State, Watch, Event } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
/**
 * A component which lets a user manage remote access requests for their screen.
 */
export class DyteRemoteAccessManager {
  constructor() {
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
  }
  disconnectedCallback() { }
  meetingChanged(meeting) {
    var _a, _b, _c, _d;
    if (meeting != null) {
      if (!Boolean(this.acceptedRequestId) && Boolean((_c = (_b = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.remote) === null || _b === void 0 ? void 0 : _b.active) === null || _c === void 0 ? void 0 : _c.id)) {
        this.acceptedRequestId = (_d = this.meeting.remote.active) === null || _d === void 0 ? void 0 : _d.id;
      }
    }
  }
  render() {
    var _a, _b, _c, _d;
    if (!Boolean((_b = (_a = this === null || this === void 0 ? void 0 : this.meeting) === null || _a === void 0 ? void 0 : _a.remote) === null || _b === void 0 ? void 0 : _b.incomingRequests.toArray().length)) {
      return (h(Host, null,
        h("p", { class: "empty-message" }, this.t('There are no remote requests, yet.'))));
    }
    return (h(Host, null,
      h("h3", null, this.t('The following people have requested remote control to your screen share')),
      h("p", null, this.t('Please select whom you want to give access to')),
      h("div", { class: "scrollbar" }, (_d = (_c = this === null || this === void 0 ? void 0 : this.meeting) === null || _c === void 0 ? void 0 : _c.remote) === null || _d === void 0 ? void 0 : _d.incomingRequests.toArray().map((incomingRequest) => {
        const requestPeer = this.meeting.participants.joined.get(incomingRequest.remotePeerId);
        return (
        // should use participant id for htmlFor instead
        h("label", { onClick: () => {
            this.acceptedRequestId = incomingRequest.id;
          }, class: "participant", htmlFor: requestPeer.id },
          h("input", { type: "radio", checked: this.acceptedRequestId === incomingRequest.id, name: "remote-access-participant", value: incomingRequest.id }),
          h("dyte-avatar", { participant: requestPeer, size: "sm" }),
          requestPeer.name));
      })),
      h("div", { id: "actions" },
        h("dyte-button", { disabled: !Boolean(this.acceptedRequestId), onClick: () => {
            var _a;
            (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.remote.acceptControl(this.acceptedRequestId);
            this.stateUpdate.emit({ activeRemoteAccessManager: false });
          } }, this.t('Grant access')))));
  }
  static get is() { return "dyte-remote-access-manager"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-remote-access-manager.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-remote-access-manager.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "States object"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "acceptedRequestId": {}
  }; }
  static get events() { return [{
      "method": "stateUpdate",
      "name": "dyteStateUpdate",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits updated state data"
      },
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      }
    }]; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }]; }
}
